X-Git-Url: https://git.xinqibao.xyz/dwm.git/blobdiff_plain/f8181f64e2ba4fca4e85036c48cf90a2151794fc..7541f1ad4980bf1c917f4fec59353f79306fdf5c:/dwm.h?ds=sidebyside

diff --git a/dwm.h b/dwm.h
index 03f8c1f..f74c17b 100644
--- a/dwm.h
+++ b/dwm.h
@@ -24,9 +24,8 @@
  *
  * Keys and tagging rules are organized as arrays and defined in the config.h
  * file. These arrays are kept static in event.o and tag.o respectively,
  * because no other part of dwm needs access to them.  The current mode is
  * represented by the arrange() function pointer, which wether points to
  * dofloat() or dotile(). 
  *
  * To understand everything else, start reading main.c:main().
  */
@@ -36,19 +35,12 @@
 
 /* mask shorthands, used in event.c and client.c */
 #define BUTTONMASK		(ButtonPressMask | ButtonReleaseMask)
-/* other stuff used in different places */
-#define BORDERPX		1
-#define PROTODELWIN		1
 
 enum { NetSupported, NetWMName, NetLast };		/* EWMH atoms */
-enum { WMProtocols, WMDelete, WMLast };			/* default atoms */
+enum { WMProtocols, WMDelete, WMState, WMLast };	/* default atoms */
 enum { CurNormal, CurResize, CurMove, CurLast };	/* cursor */
 enum { ColBorder, ColFG, ColBG, ColLast };		/* color */
 
-typedef enum {
-	TopLeft, TopRight, BotLeft, BotRight
-} Corner; /* window corners */
-
 typedef union {
 	const char *cmd;
 	int i;
@@ -74,13 +66,13 @@ typedef struct {
 typedef struct Client Client;
 struct Client {
 	char name[256];
-	int proto;
 	int x, y, w, h;
 	int rx, ry, rw, rh; /* revert geometry */
 	int basew, baseh, incw, inch, maxw, maxh, minw, minh;
+	int minax, minay, maxax, maxay;
 	long flags; 
 	unsigned int border;
-	Bool isfloat, isfixed, ismax;
+	Bool isbanned, isfixed, ismax, isversatile;
 	Bool *tags;
 	Client *next;
 	Client *prev;
@@ -88,76 +80,77 @@ struct Client {
 	Window win;
 };
 
+typedef struct {
+	const char *symbol;
+	void (*arrange)(void);
+} Layout;
+
 extern const char *tags[];			/* all tags */
 extern char stext[256];				/* status text */
-extern int bx, by, bw, bh, bmw;			/* bar geometry, bar mode label width */
 extern int screen, sx, sy, sw, sh;		/* screen geometry */
 extern int wax, way, wah, waw;			/* windowarea geometry */
+extern unsigned int bh, blw;			/* bar height, bar layout label width */
 extern unsigned int master, nmaster;		/* master percent, number of master clients */
 extern unsigned int ntags, numlockmask;		/* number of tags, dynamic lock mask */
 extern void (*handler[LASTEvent])(XEvent *);	/* event handler */
-extern void (*arrange)(void);			/* arrange function, indicates mode  */
 extern Atom wmatom[WMLast], netatom[NetLast];
-extern Bool running, issel, *seltag;		/* seltag is array of Bool */
+extern Bool selscreen, *seltag;			/* seltag is array of Bool */
 extern Client *clients, *sel, *stack;		/* global client list and stack */
 extern Cursor cursor[CurLast];
 extern DC dc;					/* global draw context */
 extern Display *dpy;
+extern Layout *lt;
 extern Window root, barwin;
 
 /* client.c */
 extern void configure(Client *c);		/* send synthetic configure event */
 extern void focus(Client *c);			/* focus c, c may be NULL */
-extern Client *getclient(Window w);		/* return client of w */
 extern void killclient(Arg *arg);		/* kill c nicely */
 extern void manage(Window w, XWindowAttributes *wa);	/* manage new client */
-extern void resize(Client *c, Bool sizehints, Corner sticky); /* resize c*/
+extern void resize(Client *c, int x, int y,
+		int w, int h, Bool sizehints);	/* resize with given coordinates c*/
+extern void toggleversatile(Arg *arg);		/* toggles focused client between versatile/and non-versatile state */
 extern void updatesizehints(Client *c);		/* update the size hint variables of c */
 extern void updatetitle(Client *c);		/* update the name of c */
 extern void unmanage(Client *c);		/* destroy c */
+extern void zoom(Arg *arg);			/* zooms the focused client to master area, arg is ignored */
 
 /* draw.c */
 extern void drawstatus(void);			/* draw the bar */
-extern unsigned long getcolor(const char *colstr);	/* return color of colstr */
-extern void setfont(const char *fontstr);	/* set the font for DC */
+extern void drawtext(const char *text,
+		unsigned long col[ColLast]);	/* draw text */
 extern unsigned int textw(const char *text);	/* return the width of text in px*/
 
 /* event.c */
 extern void grabkeys(void);			/* grab all keys defined in config.h */
-extern void procevent(void);			/* process pending X events */
+
+/* layout.c */
+extern void focusnext(Arg *arg);		/* focuses next visible client, arg is ignored  */
+extern void focusprev(Arg *arg);		/* focuses previous visible client, arg is ignored */
+extern void incnmaster(Arg *arg);		/* increments nmaster with arg's index value */
+extern void initlayouts(void);			/* initialize layout array */
+extern Client *nexttiled(Client *c);		/* returns tiled successor of c */
+extern void resizemaster(Arg *arg);		/* resizes the master percent with arg's index value */
+extern void restack(void);			/* restores z layers of all clients */
+extern void setlayout(Arg *arg);		/* sets layout, -1 toggles */
+extern void versatile(void);			/* arranges all windows versatile */
 
 /* main.c */
-extern int getproto(Window w);			/* return protocol mask of WMProtocols property of w */
 extern void quit(Arg *arg);			/* quit dwm nicely */
 extern void sendevent(Window w, Atom a, long value);	/* send synthetic event to w */
 extern int xerror(Display *dsply, XErrorEvent *ee);	/* dwm's X error handler */
 
 /* tag.c */
-extern void initrregs(void);			/* initialize regexps of rules defined in config.h */
-extern Client *getnext(Client *c);		/* returns next visible client */
-extern Client *getprev(Client *c);		/* returns previous visible client */
+extern void compileregs(void);			/* initialize regexps of rules defined in config.h */
+extern Bool isvisible(Client *c);		/* returns True if client is visible */
 extern void settags(Client *c, Client *trans);	/* sets tags of c */
 extern void tag(Arg *arg);			/* tags c with arg's index */
 extern void toggletag(Arg *arg);		/* toggles c tags with arg's index */
+extern void toggleview(Arg *arg);		/* toggles the tag with arg's index (in)visible */
+extern void view(Arg *arg);			/* views the tag with arg's index */
 
 /* util.c */
 extern void *emallocz(unsigned int size);	/* allocates zero-initialized memory, exits on error */
 extern void eprint(const char *errstr, ...);	/* prints errstr and exits with 1 */
-extern void *erealloc(void *ptr, unsigned int size);	/* reallocates memory, exits on error */
-extern void spawn(Arg *arg);			/* forks a new subprocess with to arg's cmd */
+extern void spawn(Arg *arg);			/* forks a new subprocess with arg's cmd */
 
-/* view.c */
-extern void detach(Client *c);			/* detaches c from global client list */
-extern void dofloat(void);			/* arranges all windows floating */
-extern void dotile(void);			/* arranges all windows tiled */
-extern void focusnext(Arg *arg);		/* focuses next visible client, arg is ignored  */
-extern void focusprev(Arg *arg);		/* focuses previous visible client, arg is ignored */
-extern void incnmaster(Arg *arg);		/* increments nmaster with arg's index value */
-extern Bool isvisible(Client *c);		/* returns True if client is visible */
-extern void resizemaster(Arg *arg);		/* resizes the master percent with arg's index value */
-extern void restack(void);			/* restores z layers of all clients */
-extern void togglefloat(Arg *arg);		/* toggles focusesd client between floating/non-floating state */
-extern void togglemode(Arg *arg);		/* toggles global arrange function (dotile/dofloat) */
-extern void toggleview(Arg *arg);		/* toggles the tag with arg's index (in)visible */
-extern void view(Arg *arg);			/* views the tag with arg's index */
-extern void zoom(Arg *arg);			/* zooms the focused client to master area, arg is ignored */
@@ -24,9 +24,8 @@
  * Keys and tagging rules are organized as arrays and defined in the config.h
  * file. These arrays are kept static in event.o and tag.o respectively,
- * because no other part of dwm needs access to them.  The current mode is
- * represented by the arrange() function pointer, which wether points to
- * dofloat() or dotile(). 
+ * because no other part of dwm needs access to them.  The current layout is
+ * represented by the lt pointer.
  *
  * To understand everything else, start reading main.c:main().